/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class AzureDevopsApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Core = new CoreGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Git = new GitGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Graph = new GraphGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Wiki = new WikiGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Core, this.Git, this.Graph, this.Wiki);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Core, Git, Graph, Wiki) {
        this.Core = Core;
        this.Git = Git;
        this.Graph = Graph;
        this.Wiki = Wiki;
    }
    /**
     * Get project with the specified id or name, optionally including capabilities.
     * Alternative usage: Core.Project.getProject
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/get?view=azure-devops-rest-7.2
     * @param options Request options.
     */
    async getCoreProject(options) {
        return this.Core.Project.getProject(options);
    }
    /**
     * Get all projects in the organization that the authenticated user has access to.
     * Alternative usage: Core.Project.getProjects
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCoreProjects(options) {
        return this.Core.Project.getProjects(options);
    }
    /**
     * Get a specific team.
     * Alternative usage: Core.Team.getTeam
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCoreTeam(options) {
        return this.Core.Team.getTeam(options);
    }
    /**
     * Get a list of all teams.
     * Alternative usage: Core.Team.getAllTeams
     * Documentation: https://dev.azure.com/{organization}/_apis/teams?api-version=7.2-preview.3
     * @param options Request options.
     */
    async getAllCoreTeams(options) {
        return this.Core.Team.getAllTeams(options);
    }
    /**
     * Get a list of members for a specific team.
     * Alternative usage: Core.Team.getMembersWithExtendedProperties
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-team-members-with-extended-properties?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCoreTeamMembersWithExtendedProperties(options) {
        return this.Core.Team.getMembersWithExtendedProperties(options);
    }
    /**
     * Get a list of teams.
     * Alternative usage: Core.Team.getTeams
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-teams?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCoreTeams(options) {
        return this.Core.Team.getTeams(options);
    }
    /**
     * Retrieve a particular commit.
     * Alternative usage: Git.Commit.getCommit
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitCommit(options) {
        return this.Git.Commit.getCommit(options);
    }
    /**
     * Retrieve changes for a particular commit.
     * Alternative usage: Git.Commit.getChanges
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-changes?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitChanges(options) {
        return this.Git.Commit.getChanges(options);
    }
    /**
     * Retrieve git commits for a project
     * Alternative usage: Git.Commit.getCommits
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitCommits(options) {
        return this.Git.Commit.getCommits(options);
    }
    /**
     * Retrieve a list of commits associated with a particular push.
     * Alternative usage: Git.Commit.getPushCommits
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-push-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitPushCommits(options) {
        return this.Git.Commit.getPushCommits(options);
    }
    /**
     * Retrieve a git repository.
     * Alternative usage: Git.Repository.getRepository
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitRepository(options) {
        return this.Git.Repository.getRepository(options);
    }
    /**
     * Retrieve git repositories.
     * Alternative usage: Git.Repository.getRepositories
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGitRepositories(options) {
        return this.Git.Repository.getRepositories(options);
    }
    /**
     * Get a user by its descriptor.
     * Alternative usage: Graph.User.getUser
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getGraphUser(options) {
        return this.Graph.User.getUser(options);
    }
    /**
  * Get a list of all users in a given scope.
  
  Since the list of users may be large, results are returned in pages of users.  If there are more results
   than can be returned in a single page, the result set will contain a continuation token for retrieval of the
   next set of results.
  * Alternative usage: Graph.User.getUsers
  * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/list?view=azure-devops-rest-7.2&tabs=HTTP
  * @param options Request options.
  */
    async getGraphUsers(options) {
        return this.Graph.User.getUsers(options);
    }
    /**
     * Creates the wiki resource.
     * Alternative usage: Wiki.createWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/create?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async createWiki(options) {
        return this.Wiki.createWiki(options);
    }
    /**
     * Gets all wikis in a project or collection.
     * Alternative usage: Wiki.getWikis
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getWikis(options) {
        return this.Wiki.getWikis(options);
    }
    /**
     * Deletes the wiki corresponding to the wiki ID or wiki name provided.
     * Alternative usage: Wiki.deleteWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/delete?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async deleteWiki(options) {
        return this.Wiki.deleteWiki(options);
    }
    /**
     * Gets the wiki corresponding to the wiki ID or wiki name provided.
     * Alternative usage: Wiki.getWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getWiki(options) {
        return this.Wiki.getWiki(options);
    }
    /**
     * Updates the wiki corresponding to the wiki ID or wiki name provided using the update parameters.
     * Alternative usage: Wiki.editWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/update?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async editWiki(options) {
        return this.Wiki.editWiki(options);
    }
}
class CoreGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Project = new CoreProjectGroup(implementation, this.getGlobalErrorStrategy);
        this.Team = new CoreTeamGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class CoreProjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get project with the specified id or name, optionally including capabilities.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/get?view=azure-devops-rest-7.2
     * @param options Request options.
     */
    async getProject(options) {
        const { headers, errorStrategy, organization, projectId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/projects/${encodeURIComponent(projectId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get all projects in the organization that the authenticated user has access to.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getProjects(options) {
        const { headers, errorStrategy, organization, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/projects`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class CoreTeamGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a specific team.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getTeam(options) {
        const { headers, errorStrategy, organization, projectId, teamId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/projects/${encodeURIComponent(projectId)}/teams/${encodeURIComponent(teamId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of all teams.
     * Documentation: https://dev.azure.com/{organization}/_apis/teams?api-version=7.2-preview.3
     * @param options Request options.
     */
    async getAllTeams(options) {
        const { headers, errorStrategy, organization, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/teams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of members for a specific team.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-team-members-with-extended-properties?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getMembersWithExtendedProperties(options) {
        const { headers, errorStrategy, organization, projectId, teamId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/projects/${encodeURIComponent(projectId)}/teams/${encodeURIComponent(teamId)}/members`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of teams.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-teams?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getTeams(options) {
        const { headers, errorStrategy, organization, projectId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/_apis/projects/${encodeURIComponent(projectId)}/teams`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Commit = new GitCommitGroup(implementation, this.getGlobalErrorStrategy);
        this.Repository = new GitRepositoryGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class GitCommitGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Retrieve a particular commit.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCommit(options) {
        const { headers, errorStrategy, organization, commitId, repositoryId, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories/${encodeURIComponent(repositoryId)}/commits/${encodeURIComponent(commitId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve changes for a particular commit.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-changes?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getChanges(options) {
        const { headers, errorStrategy, organization, commitId, repositoryId, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories/${encodeURIComponent(repositoryId)}/commits/${encodeURIComponent(commitId)}/changes`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve git commits for a project
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getCommits(options) {
        const { headers, errorStrategy, organization, repositoryId, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories/${encodeURIComponent(repositoryId)}/commits`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve a list of commits associated with a particular push.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-push-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getPushCommits(options) {
        const { headers, errorStrategy, organization, repositoryId, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories/${encodeURIComponent(repositoryId)}/commits`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GitRepositoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Retrieve a git repository.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getRepository(options) {
        const { headers, errorStrategy, organization, repositoryId, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories/${encodeURIComponent(repositoryId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Retrieve git repositories.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getRepositories(options) {
        const { headers, errorStrategy, organization, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/git/repositories`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GraphGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.User = new GraphUserGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class GraphUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a user by its descriptor.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getUser(options) {
        const { headers, errorStrategy, organization, userDescriptor, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`https://vssps.dev.azure.com/${encodeURIComponent(organization)}/_apis/graph/users/${encodeURIComponent(userDescriptor)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Get a list of all users in a given scope.
  
  Since the list of users may be large, results are returned in pages of users.  If there are more results
   than can be returned in a single page, the result set will contain a continuation token for retrieval of the
   next set of results.
  * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/list?view=azure-devops-rest-7.2&tabs=HTTP
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, organization, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`https://vssps.dev.azure.com/${encodeURIComponent(organization)}/_apis/graph/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WikiGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Creates the wiki resource.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/create?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async createWiki(options) {
        const { body, headers, errorStrategy, organization, project, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/wiki/wikis`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets all wikis in a project or collection.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getWikis(options) {
        const { headers, errorStrategy, organization, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/wiki/wikis`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes the wiki corresponding to the wiki ID or wiki name provided.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/delete?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async deleteWiki(options) {
        const { headers, errorStrategy, organization, wikiIdentifier, project, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/wiki/wikis/${encodeURIComponent(wikiIdentifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Gets the wiki corresponding to the wiki ID or wiki name provided.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async getWiki(options) {
        const { headers, errorStrategy, organization, wikiIdentifier, project, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/wiki/wikis/${encodeURIComponent(wikiIdentifier)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates the wiki corresponding to the wiki ID or wiki name provided using the update parameters.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/update?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    async editWiki(options) {
        const { body, headers, errorStrategy, organization, wikiIdentifier, project, ...queryParams } = options;
        const request = new Request("PATCH", constructUrl(`/${encodeURIComponent(organization)}/${encodeURIComponent(project)}/_apis/wiki/wikis/${encodeURIComponent(wikiIdentifier)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map